@@ -1,9 +1,9 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * FEEL parser.
+ * MIT license
  *
- * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -12,6 +12,22 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
+ * Apache license, Version 2.0
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 use super::accept;
@@ -146,7 +162,6 @@ fn _0008() {
   assert!(crate::parse_name(&scope, "5Cards", false).is_err());
 }
 
-/// Covers the case when a name is expected but a number encountered.
 #[test]
 fn _0009() {
   let scope = scope!();
@@ -197,3 +212,40 @@ fn _0010() {
   accept_name(&scope, "bo++e--m*", "bo++e--m*");
   accept_name(&scope, "wh*t*v*r", "wh*t*v*r");
 }
+
+#[test]
+fn _0011() {
+  let scope = scope!();
+  scope.set_entry(&"?".into(), value_null!());
+  accept(
+    &scope,
+    StartTextualExpression,
+    "?.Rating > 0",
+    r#"
+       Gt
+       ├─ Path
+       │  ├─ Name
+       │  │  └─ `?`
+       │  └─ Name
+       │     └─ `Rating`
+       └─ Numeric
+          └─ `0.`
+    "#,
+    false,
+  );
+}
+
+#[test]
+fn _0012() {
+  let scope = scope!();
+  accept(
+    &scope,
+    StartTextualExpression,
+    "?",
+    r#"
+       Name
+       └─ `?`
+    "#,
+    false,
+  );
+}
